Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(645)

Unified Diff: pnacl/driver/pnacl-driver.py

Issue 581463004: NonSFI mode: Add libcrt_platform for native/mixed linking. (Closed) Base URL: https://chromium.googlesource.com/native_client/src/native_client.git@master
Patch Set: Created 6 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: pnacl/driver/pnacl-driver.py
diff --git a/pnacl/driver/pnacl-driver.py b/pnacl/driver/pnacl-driver.py
index 5621fb1ee280eefaee0db5b8263d379cf9d493a6..384472a680d84a1a43bfc1f4f6e2bfd1a1e9a0a6 100755
--- a/pnacl/driver/pnacl-driver.py
+++ b/pnacl/driver/pnacl-driver.py
@@ -494,10 +494,12 @@ def main(argv):
if env.getbool('ALLOW_NATIVE'):
if not compiling_to_native:
Log.Fatal("--pnacl-allow-native without -arch is not meaningful.")
# For native/mixed links, also bring in the native libgcc to avoid link
# failure if pre-translated native code needs functions from it.
env.append('LD_FLAGS', env.eval('-L${LIBS_NATIVE_ARCH}'))
env.append('STDLIBS', '-lgcc')
+ env.append('STDLIBS', '-lcrt_platform')
if not env.get('STDLIB'):
« no previous file with comments | « no previous file | no next file » | no next file with comments »
@@ -494,10 +494,12 @@ def main(argv):
if not compiling_to_native:
Log.Fatal("--pnacl-allow-native without -arch is not meaningful.")
- # For native/mixed links, also bring in the native libgcc to avoid link
- # failure if pre-translated native code needs functions from it.
+ # For native/mixed links, also bring in the native libgcc and
+ # libcrt_platform to avoid link failure if pre-translated native
+ # code needs functions from it.
env.append('LD_FLAGS', env.eval('-L${LIBS_NATIVE_ARCH}'))
env.append('STDLIBS', '-lgcc')

Powered by Google App Engine
This is Rietveld 408576698